@@ -1,16 +1,17 @@
 use super::neighbors;
-use crate::{error::InvalidGeometry, CellIndex, LatLng, Resolution, TWO_PI};
+use crate::{CellIndex, LatLng, Resolution, TWO_PI, error::InvalidGeometry};
 use ahash::{HashSet, HashSetExt};
 use either::Either;
 use float_eq::float_eq;
 use geo::{
+    BooleanOps as _, BoundingRect as _, Centroid as _, Coord, CoordsIter as _,
+    Intersects, Line, LineString, MultiPolygon, Polygon, Rect, Relate as _,
+    ToRadians as _,
     algorithm::{
-        coordinate_position::{coord_pos_relative_to_ring, CoordPos},
+        coordinate_position::{CoordPos, coord_pos_relative_to_ring},
         relate::PreparedGeometry,
     },
-    coord, BooleanOps as _, BoundingRect as _, Centroid as _, Coord,
-    CoordsIter as _, Intersects, Line, LineString, MultiPolygon, Polygon, Rect,
-    Relate as _, ToRadians as _,
+    coord,
 };
 use std::{
     cmp,
@@ -84,7 +85,7 @@ impl Tiler {
     ///     LineString::from(vec![(0., 0.), (1., 1.), (1., 0.), (0., 0.)]),
     ///     vec![],
     /// );
-    /// let mut tiler = TilerBuilder::new(Resolution::Ten)
+    /// let mut tiler = TilerBuilder::new(Resolution::Six)
     ///     .containment_mode(ContainmentMode::Covers)
     ///     .build();
     /// tiler.add(polygon)?;
@@ -141,7 +142,7 @@ impl Tiler {
     ///     LineString::from(vec![(0., 0.), (1., 1.), (1., 0.), (0., 0.)]),
     ///     vec![],
     /// );
-    /// let mut tiler = TilerBuilder::new(Resolution::Ten)
+    /// let mut tiler = TilerBuilder::new(Resolution::Six)
     ///     .containment_mode(ContainmentMode::Covers)
     ///     .build();
     /// tiler.add(polygon)?;
@@ -252,12 +253,6 @@ impl Tiler {
         scratchpad: &mut [u64],
         predicate: &ContainmentPredicate<'_>,
     ) -> Vec<(CellIndex, bool)> {
-        // IIUC, the collect is necessary to consume the iterator and release
-        // the mutable borrow on `already_seen`.
-        #[expect(
-            clippy::needless_collect,
-            reason = "needed because mutable borrow"
-        )]
         // Compute the set of cells making the outlines of the polygon.
         let outlines = self
             .interiors()
@@ -319,7 +314,7 @@ pub struct TilerBuilder {
 }
 
 impl TilerBuilder {
-    /// Initializes a new plotter builder with default settings.
+    /// Initializes a new tiler builder with default settings.
     #[must_use]
     pub const fn new(resolution: Resolution) -> Self {
         Self {
@@ -356,7 +351,7 @@ impl TilerBuilder {
         self
     }
 
-    /// Builds the plotter.
+    /// Builds the tiler.
     #[must_use]
     pub fn build(self) -> Tiler {
         Tiler {
@@ -426,6 +421,7 @@ struct PredicateResult {
     is_fully_contained: bool,
 }
 
+#[expect(clippy::large_enum_variant, reason = "used once, on the stack")]
 enum ContainmentPredicate<'geom> {
     ContainsCentroid(&'geom MultiPolygon, MultiBBoxes),
     IntersectsBoundary(PreparedGeometry<'geom, &'geom MultiPolygon>),
@@ -853,7 +849,7 @@ fn ring_contains_centroid(
 }
 
 // Return the cell boundary, in radians.
-fn cell_boundary(cell: CellIndex) -> MultiPolygon {
+pub fn cell_boundary(cell: CellIndex) -> MultiPolygon {
     let boundary = LineString(
         cell.boundary()
             .iter()
