@@ -1,24 +1,26 @@
 use super::{Children, GridPathCells, Triangle};
 use crate::{
+    BaseCell, Boundary, CCW, CW, DEFAULT_CELL_INDEX, DirectedEdgeIndex,
+    Direction, EARTH_RADIUS_KM, Edge, ExtendedResolution, FaceSet, LatLng,
+    LocalIJ, NUM_HEX_VERTS, NUM_PENT_VERTS, Resolution, Vertex, VertexIndex,
     coord::{CoordIJ, CoordIJK, FaceIJK, LocalIJK, Overage},
     error::{
         CompactionError, HexGridError, InvalidCellIndex, LocalIjError,
         ResolutionMismatch,
     },
     grid,
-    index::{bits, IndexMode},
-    BaseCell, Boundary, DirectedEdgeIndex, Direction, Edge, ExtendedResolution,
-    FaceSet, LatLng, LocalIJ, Resolution, Vertex, VertexIndex, CCW, CW,
-    DEFAULT_CELL_INDEX, EARTH_RADIUS_KM, NUM_HEX_VERTS, NUM_PENT_VERTS,
+    index::{IndexMode, bits},
 };
 use alloc::vec::Vec;
 use core::{
     cmp::Ordering,
     fmt, iter,
-    num::{NonZeroU64, NonZeroU8},
+    num::{NonZeroU8, NonZeroU64},
     str::FromStr,
 };
 use either::Either;
+#[cfg(feature = "geo")]
+use geo::ToDegrees as _;
 
 /// Lookup table for number of children for hexagonal cells.
 // 7.pow(resolution_delta)
@@ -212,7 +214,11 @@ impl CellIndex {
     ///
     /// ```
     /// let index = h3o::CellIndex::try_from(0x8a1fb46622dffff)?;
-    /// assert_eq!(index.area_rads2(), 3.3032558516982826e-10);
+    /// float_eq::assert_float_eq!(
+    ///     index.area_rads2(),
+    ///     3.3032558516982826e-10,
+    ///     abs <= 1e-11
+    /// );
     /// # Ok::<(), h3o::error::InvalidCellIndex>(())
     /// ```
     #[must_use]
@@ -234,7 +240,11 @@ impl CellIndex {
     ///
     /// ```
     /// let index = h3o::CellIndex::try_from(0x8a1fb46622dffff)?;
-    /// assert_eq!(index.area_km2(), 0.013407827139722947);
+    /// float_eq::assert_float_eq!(
+    ///     index.area_km2(),
+    ///     0.013407827139722947,
+    ///     abs <= 1e-11
+    /// );
     /// # Ok::<(), h3o::error::InvalidCellIndex>(())
     /// ```
     #[must_use]
@@ -248,7 +258,11 @@ impl CellIndex {
     ///
     /// ```
     /// let index = h3o::CellIndex::try_from(0x8a1fb46622dffff)?;
-    /// assert_eq!(index.area_m2(), 13407.827139722947);
+    /// float_eq::assert_float_eq!(
+    ///     index.area_m2(),
+    ///     13407.827139722947,
+    ///     abs <= 1e-5
+    /// );
     /// # Ok::<(), h3o::error::InvalidCellIndex>(())
     /// ```
     #[must_use]
@@ -513,7 +527,7 @@ impl CellIndex {
                     // Adjust digit index for deleted K-subsequence.
                     if parent_is_pentagon && digit > 0 {
                         digit -= 1;
-                    };
+                    }
                     if digit == 0 {
                         return 0;
                     }
@@ -651,7 +665,7 @@ impl CellIndex {
     /// ```
     /// use h3o::CellIndex;
     ///
-    /// let cells = [
+    /// let mut cells = [
     ///     0x081003ffffffffff,
     ///     0x081023ffffffffff,
     ///     0x081043ffffffffff,
@@ -663,7 +677,7 @@ impl CellIndex {
     /// .into_iter()
     /// .map(|hex| CellIndex::try_from(hex))
     /// .collect::<Result<Vec<_>, _>>()?;
-    /// CellIndex::compact_in_place(cells)?;
+    /// CellIndex::compact(&mut cells)?;
     /// # Ok::<(), Box<dyn std::error::Error>>(())
     /// ```
     pub fn compact(cells: &mut Vec<Self>) -> Result<(), CompactionError> {
@@ -1919,6 +1933,27 @@ impl TryFrom<u64> for CellIndex {
     }
 }
 
+/// Return the geometry of this cell.
+///
+/// If it crosses the anti-meridian, two polygons are returned.
+///
+/// # Example
+///
+/// ```
+/// let cell = h3o::CellIndex::try_from(0x8a1fb46622dffff)?;
+/// let geom = geo::MultiPolygon::from(cell);
+/// # Ok::<(), h3o::error::InvalidCellIndex>(())
+/// ```
+#[cfg(feature = "geo")]
+impl From<CellIndex> for geo::MultiPolygon {
+    fn from(cell: CellIndex) -> Self {
+        let mut polygons = crate::geom::cell_boundary(cell);
+        // converts back everything to degrees
+        polygons.to_degrees_in_place();
+        polygons
+    }
+}
+
 impl FromStr for CellIndex {
     type Err = InvalidCellIndex;
 
@@ -1974,14 +2009,6 @@ impl fmt::UpperHex for CellIndex {
     }
 }
 
-#[cfg(feature = "geo")]
-impl From<CellIndex> for geo::Polygon {
-    fn from(value: CellIndex) -> Self {
-        let boundary: geo::LineString = value.boundary().into();
-        Self::new(boundary, Vec::new())
-    }
-}
-
 #[cfg(feature = "arbitrary")]
 impl<'a> arbitrary::Arbitrary<'a> for CellIndex {
     fn arbitrary(
@@ -2083,7 +2110,7 @@ struct Cursor<'a> {
 }
 
 impl<'a> Cursor<'a> {
-    fn new(buffer: &'a mut Vec<CellIndex>) -> Self {
+    const fn new(buffer: &'a mut Vec<CellIndex>) -> Self {
         Self {
             buffer,
             rd_idx: 0,
