@@ -1,6 +1,7 @@
 // MSRV: switch to #[expect] when MSRV is 1.81
 #[allow(
 	clippy::doc_lazy_continuation,
+	clippy::doc_overindented_list_items,
 	clippy::double_must_use,
 	clippy::excessive_precision,
 	clippy::let_and_return,
@@ -23,3 +24,6 @@
 pub mod hub {
 	include!(concat!(env!("OUT_DIR"), "/opencv/hub.rs"));
 }
+mod cond_macros {
+	include!(concat!(env!("OUT_DIR"), "/opencv/cond_macros.rs"));
+}
