@@ -111,7 +111,7 @@ impl<'tu, 'ge> Class<'tu, 'ge> {
 	pub fn type_ref(&self) -> TypeRef<'tu, 'ge> {
 		match self {
 			&Self::Clang { entity, gen_env, .. } => TypeRef::new(entity.get_type().expect("Can't get class type"), gen_env),
-			Self::Desc(desc) => TypeRef::guess(desc.cpp_fullname.as_ref(), Rc::clone(&desc.rust_module)),
+			Self::Desc(desc) => TypeRef::guess(desc.cpp_fullname.as_ref(), desc.rust_module),
 		}
 	}
 
@@ -149,7 +149,7 @@ impl<'tu, 'ge> Class<'tu, 'ge> {
 		}
 	}
 
-	/// True if class has virtual methods
+	/// True if a class has virtual methods
 	pub fn is_polymorphic(&self) -> bool {
 		match self {
 			Self::Clang { entity, .. } => entity
@@ -159,7 +159,7 @@ impl<'tu, 'ge> Class<'tu, 'ge> {
 		}
 	}
 
-	/// Special case of an empty class with only an anonymous enum inside (e.g. DrawLinesMatchesFlags)
+	/// Special case of an empty class with only an anonymous enum inside (e.g., DrawLinesMatchesFlags)
 	pub fn as_enum(&self) -> Option<Enum<'tu>> {
 		match self {
 			&Self::Clang { entity, .. } => {
@@ -241,7 +241,7 @@ impl<'tu, 'ge> Class<'tu, 'ge> {
 			&Self::Clang { entity, gen_env, .. } => {
 				let mut out = vec![];
 				let entity = entity.get_template().unwrap_or(entity);
-				entity.walk_bases_while(|child| {
+				let _ = entity.walk_bases_while(|child| {
 					out.push(Self::new(Self::definition_entity(child), gen_env));
 					ControlFlow::Continue(())
 				});
@@ -333,7 +333,7 @@ impl<'tu, 'ge> Class<'tu, 'ge> {
 		match self {
 			Class::Clang { entity, gen_env, .. } => {
 				let mut out = Vec::with_capacity(32);
-				entity.walk_methods_while(|func_entity| {
+				let _ = entity.walk_methods_while(|func_entity| {
 					let func = Func::new(func_entity, gen_env);
 					let func: Func = if let Some(func_fact) = gen_env.settings.func_replace.get(&mut func.matcher()) {
 						func_fact(&func)
@@ -384,7 +384,7 @@ impl<'tu, 'ge> Class<'tu, 'ge> {
 
 	pub fn fields(&self, filter: impl Fn(&Field) -> bool) -> Vec<Field<'tu, 'ge>> {
 		let mut out = Vec::with_capacity(32);
-		self.for_each_field(|f| {
+		let _ = self.for_each_field(|f| {
 			if filter(&f) {
 				out.push(f);
 			}
@@ -403,7 +403,7 @@ impl<'tu, 'ge> Class<'tu, 'ge> {
 
 	pub fn consts(&self) -> Vec<Const<'tu>> {
 		let mut out = Vec::with_capacity(8);
-		self.for_each_const(|c| {
+		let _ = self.for_each_const(|c| {
 			out.push(c);
 			ControlFlow::Continue(())
 		});
@@ -421,7 +421,7 @@ impl<'tu, 'ge> Class<'tu, 'ge> {
 				let accessor_generator = move |fld: &Field<'tu, 'ge>| {
 					let doc_comment = Rc::from(fld.doc_comment());
 					let def_loc = fld.file_line_name().location;
-					let rust_module = Rc::from(fld.rust_module());
+					let rust_module = fld.rust_module();
 					let mut fld_type_ref = fld.type_ref();
 					let fld_refname = fld.cpp_name(CppNameStyle::Reference);
 					if let Some(type_hint) = gen_env.settings.property_override.get(fld_refname.as_ref()) {
@@ -457,7 +457,7 @@ impl<'tu, 'ge> Class<'tu, 'ge> {
 										Constness::Const,
 										return_kind,
 										fld_declname,
-										Rc::clone(&rust_module),
+										rust_module,
 										[],
 										fld_type_ref.as_ref().clone().with_inherent_constness(Constness::Const),
 									)
@@ -476,7 +476,7 @@ impl<'tu, 'ge> Class<'tu, 'ge> {
 										Constness::Mut,
 										return_kind,
 										format!("{fld_declname}Mut"),
-										Rc::clone(&rust_module),
+										rust_module,
 										[],
 										fld_type_ref.as_ref().clone().with_inherent_constness(Constness::Mut),
 									)
@@ -497,7 +497,7 @@ impl<'tu, 'ge> Class<'tu, 'ge> {
 										fld_const,
 										return_kind,
 										fld_declname,
-										Rc::clone(&rust_module),
+										rust_module,
 										[],
 										fld_type_ref.as_ref().clone(),
 									)
@@ -526,7 +526,7 @@ impl<'tu, 'ge> Class<'tu, 'ge> {
 								Constness::Mut,
 								ReturnKind::InfallibleNaked,
 								format!("set{first_letter}{rest}"),
-								Rc::clone(&rust_module),
+								rust_module,
 								[Field::new_desc(FieldDesc {
 									cpp_fullname: "val".into(),
 									type_ref: fld_type_ref.as_ref().clone().with_inherent_constness(Constness::Const),
