@@ -16,7 +16,7 @@ impl RustNativeGeneratedElement for AbstractRefWrapper<'_, '_> {
 
 	fn element_safe_id(&self) -> String {
 		let type_ref = self.type_ref();
-		format!("{}-{}", type_ref.rust_module(), type_ref.rust_safe_id(true))
+		format!("{}-{}", type_ref.rust_module().opencv_name(), type_ref.rust_safe_id(true))
 	}
 
 	fn gen_rust(&self, _opencv_version: &str) -> String {
